using System;
using System.Runtime.InteropServices;
using System.Collections.Generic;
using System.Text;

namespace JoyLib
{
    public class JoystickState
    {
        public enum Axis
        {
            X,
            Y,
            Z,
            R,
            U,
            V
        }
        int[] axisPos = new int[6];
        bool[] buttonState = new bool[32];

        int POV;

        internal JoystickState(JoyInfoEx jie)
        {
            axisPos[(int)Axis.X] = jie.dwXpos;
            axisPos[(int)Axis.Y] = jie.dwYpos;
            axisPos[(int)Axis.Z] = jie.dwZpos;
            axisPos[(int)Axis.R] = jie.dwRpos;
            axisPos[(int)Axis.U] = jie.dwUpos;
            axisPos[(int)Axis.V] = jie.dwVpos;

            for (int i = 0; i < 32; i++)
            {
                buttonState[i] = (0 != (jie.dwButtons & (1 << i)));
            }

            POV = jie.dwPOV;
        }

        public int GetAxis(Axis ax)
        {
            return axisPos[(int)ax];
        }

        public bool GetButton(int button)
        {
            return buttonState[button];
        }

        public enum POVDir
        {
            Left,
            Right,
            Up,
            Down
        }

        public bool IsPOVPressed(POVDir d)
        {
            // pov is angle in degrees times 100
            int angle = POV / 100;
            switch (d)
            {
                case POVDir.Up:
                    return (angle < 90) || (angle > 270 && angle < 360);
                case POVDir.Down:
                    return (angle > 90) && (angle < 270);
                case POVDir.Right:
                    return (angle > 0) && (angle < 180);
                case POVDir.Left:
                    return (angle > 180) && (angle < 360);
                default:
                    return false;
            }
        }
    }
}
